==> fheroes2_1.1.8+dfsg.orig.tar.xz: fheroes2-1.1.8/src/fheroes2/game/game_string.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2025                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <cstdint>
#include <optional>
#include <string>

class IStreamBase;
class OStreamBase;

namespace fheroes2
{

    enum class SupportedLanguage : uint8_t;

    struct LocalizedString
    {
        std::string text;

        std::optional<SupportedLanguage> language;
    };
}

OStreamBase & operator<<( OStreamBase & stream, const fheroes2::LocalizedString & string );
IStreamBase & operator>>( IStreamBase & stream, fheroes2::LocalizedString & string );

==> fheroes2_1.1.12+dfsg.orig.tar.xz: fheroes2-1.1.12+dfsg/src/fheroes2/game/game_string.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2025                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <cstdint>
#include <optional>
#include <string>
#include <utility>

class IStreamBase;
class OStreamBase;

namespace fheroes2
{
    enum class SupportedLanguage : uint8_t;

    struct LocalizedString
    {
        LocalizedString() = default;

        LocalizedString( std::string text_, std::optional<SupportedLanguage> language_ )
            : text( std::move( text_ ) )
            , language( language_ )
        {
            // Do nothing.
        }

        std::string text;

        std::optional<SupportedLanguage> language;
    };
}

OStreamBase & operator<<( OStreamBase & stream, const fheroes2::LocalizedString & string );
IStreamBase & operator>>( IStreamBase & stream, fheroes2::LocalizedString & string );
